@@ -114,6 +114,10 @@ class Status:
                         "item": self.father.framework.machine.info["tool_table"][0]
                     }
 
+                    current_gcode = next((code for code in self.father.framework.machine.info["gcodes"] if 540 <= code <= 593), None)
+                    if current_gcode:
+                        user_data["data"]["current_gcode"] = "G" + str(current_gcode)
+
                     if user_data["task_state"] == 4:
                         self.father.framework.machine.task_state = True
                     else:
