@@ -16,7 +16,7 @@ class Machine:
         self.axis_tmp = ""
         self.is_alive = False
         self.info = None
-        self.data = {"index": 0, "position": {}, "velocity": {}, "g_offset": {}, "g5x_offset": {}, "g92_offset": {}, "dtg_offset": {}, "tool": {}, "options": []}
+        self.data = {"index": 0, "position": {}, "velocity": {}, "current_gcode": "", "g_offset": {}, "g5x_offset": {}, "g92_offset": {}, "dtg_offset": {}, "tool": {}, "options": []}
         self.machine_path = ""
         self.workspace = "/opt/armcnc"
         self.task_state = False
@@ -25,10 +25,13 @@ class Machine:
         self.data["index"] = index
         if len(self.data["options"]) == 0:
             for key, val in enumerate(range(10)):
-                if key > 6:
-                    self.data["options"].append({"label": "P" + str(key) + " G59." + str((key - 7) + 1), "p_name": "P" + str(key), "value": key, "name": "G59." + str((key - 7) + 1)})
+                if key == 0:
+                    self.data["options"].append({"label": "P0 Current", "p_name": "", "value": 0, "name": ""})
                 else:
-                    self.data["options"].append({"label": "P" + str(key) + " G5" + str(key + 3), "p_name": "P" + str(key), "value": key, "name": "G5" + str(key + 3)})
+                    if key > 6:
+                        self.data["options"].append({"label": "P" + str(key) + " G59." + str((key - 7) + 1), "p_name": "P" + str(key), "value": key, "name": "G59." + str((key - 7) + 1)})
+                    else:
+                        self.data["options"].append({"label": "P" + str(key) + " G5" + str(key + 3), "p_name": "P" + str(key), "value": key, "name": "G5" + str(key + 3)})
         return self.data
 
     def get_data(self):
@@ -44,6 +47,11 @@ class Machine:
         num = self.axis_tmp.find(axis.upper())
         return num
 
+    def get_axis_name(self, num):
+        self.axis_tmp = "XYZABCUVW"
+        name = self.axis_tmp[num]
+        return name
+
     def get_user_config_value(self, father, value):
         config = configparser.ConfigParser()
         config.read(self.workspace + "/configs/" + self.machine_path + "/machine.user")
